use utf8;
package Lilith::Schema;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Schema';

__PACKAGE__->load_namespaces;


# Created by DBIx::Class::Schema::Loader v0.07049 @ 2026-03-15 20:03:16
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:aO+/s2fYL0UYzF6bG0ldZA

our $VERSION = 2;

1;
